===================================
zodb.py3migrate - ZODB and Python 3
===================================

If you have a ZODB_ database written using Python 2.x this package helps you to
get your database ready for using it with Python 3. It is able to:

* display objects which need to be converted,

* do most of the the conversion for you,

* and switch the database file to be readable in a process running Python 3.

This package is compatible with Python version 2.7.

.. _ZODB : http://zodb.org
